@@ -1,6 +1,6 @@
-## Variance-weighted adaptive Sum of powered score (SPUw) test; using permutations to get the p-values (NO adjustment for covariates yet).
+## Variance-weighted adaptive Sum of powered score (SPUw) test; using simulation from the distribution to get the p-values.
 ##
-## It gives the p-values of the SPUw test and aSPUw test based on based on the permutation of residuals.  (NO adjustment for covariates yet)
+## It gives the p-values of the SPUw test and aSPUw test based on based on the permutation of residuals.
 ##
 ## @param Y phenotype data. It can be disease lables; =0 for controls, =1 for cases.
 ##     or It can be any quantitative traits. Vector with length n (number of observations)
@@ -37,7 +37,7 @@ aSPUwsim <- function(Y, X, cov = NULL, model=c("gaussian","binomial"), pow=c(1:8
 
     if (is.null(cov)){
         ## NO nuisance parameters:
-        Xg <- X
+        XUs <- Xg <- X
         Xbar<-apply(Xg, 2, mean)
         subtract<-function(x, y) { x - y }
         Xgb=t(apply(Xg, 1, subtract, Xbar))
@@ -54,18 +54,17 @@ aSPUwsim <- function(Y, X, cov = NULL, model=c("gaussian","binomial"), pow=c(1:8
         tdat1<-data.frame(trait=Y, cov)
         fit1<-glm(trait~.,family=model,data=tdat1)
         pis<-fitted.values(fit1)
-        Us<-matrix(0, nrow=n, ncol=k)
+        XUs<-matrix(0, nrow=n, ncol=k)
         for(i in 1:k){
             tdat2<-data.frame(X1=X[,i], cov)
             fit2<-glm(X1~.,data=tdat2)
             X1mus<-fitted.values(fit2)
-            r <- Y - pis
-            Us[, i]<-(Y - pis)*(X[,i] - X1mus)
+            XUs[, i] <- (X[,i] - X1mus)
         }
-        U<-apply(Us, 2, sum)
+        U <- t(XUs) %*% (Y - pis)
         CovS<-matrix(0, nrow=k, ncol=k)
         for(i in 1:n)
-            CovS<-CovS + Us[i,] %*% t(Us[i,])
+            CovS<-CovS + XUs[i,] %*% t(XUs[i,])
     }
 
 
@@ -73,8 +72,8 @@ aSPUwsim <- function(Y, X, cov = NULL, model=c("gaussian","binomial"), pow=c(1:8
     Vs<-diag(CovS)
     diagSDs<-ifelse(Vs>1e-20, sqrt(Vs), 1e-10)
 
-#    svd.CovS<-svd(CovS)
-#    CovSsqrt<-svd.CovS$u %*% diag(sqrt(svd.CovS$d))
+    svd.CovS<-svd(CovS)
+    CovSsqrt<-svd.CovS$u %*% diag(sqrt(svd.CovS$d))
 
 
    # test stat's:
@@ -93,8 +92,10 @@ aSPUwsim <- function(Y, X, cov = NULL, model=c("gaussian","binomial"), pow=c(1:8
     for (j in 1:length(pow)){
         set.seed(s) # to ensure the same samples are drawn for each pow
         for(b in 1:n.perm){
-            r0 <- sample(r, length(r))
-            U0<-as.vector( t(Xg) %*% r0)
+            U00<-rnorm(k, 0, 1)
+            U0<-CovSsqrt %*% U00
+#            r0 <- sample(r, length(r))
+#            U0<-as.vector( t(XUs) %*% r0)
      # test stat's:
             if (pow[j] < Inf) {T0s[b] = round( sum((U0/diagSDs)^pow[j]), digits=8) }
             if (pow[j] == Inf) {T0s[b] = round( max(abs(U0/diagSDs)), digits=8)}
